@@ -353,7 +353,7 @@ async def littleangel(
     text_w, _ = font.getsize(text)
     draw.text((300 - text_w / 2, img_h + 180), text, font=font, fill=(0, 0, 0))
 
-    name = (args and args[0]) or users[0].name or ta
+    name = (args[0] if args else "") or users[0].name or ta
     text = f"请问你们看到{name}了吗?"
     fontsize = await fit_font_size(text, 560, 110, fontname, 70, 25)
     if not fontsize:
@@ -449,3 +449,50 @@ async def worship(users: List[UserInfo], **kwargs) -> BytesIO:
         frame.paste(bg, mask=bg)
         frames.append(frame)
     return save_gif(frames, 0.04)
+
+
+async def eat(users: List[UserInfo], **kwargs) -> BytesIO:
+    img = resize(users[0].img, (32, 32))
+    frames = []
+    for i in range(3):
+        frame = Image.new("RGBA", (60, 67), (255, 255, 255, 0))
+        frame.paste(img, (1, 38))
+        bg = await load_image(f"eat/{i}.png")
+        frame.paste(bg, mask=bg)
+        frames.append(frame)
+    return save_gif(frames, 0.05)
+
+
+async def bite(users: List[UserInfo], **kwargs) -> BytesIO:
+    img = users[0].img
+    raw_frames = []
+    for i in range(16):
+        raw_frame = await load_image(f"bite/{i}.png")
+        raw_frames.append(raw_frame)
+    frames = []
+    locs = [
+        (90, 90, 105, 150),
+        (90, 83, 96, 172),
+        (90, 90, 106, 148),
+        (88, 88, 97, 167),
+        (90, 85, 89, 179),
+        (90, 90, 106, 151),
+    ]
+    for i in range(6):
+        frame = Image.new("RGBA", (362, 364), (255, 255, 255, 0))
+        x, y, w, h = locs[i]
+        frame.paste(resize(img, (w, h)), (x, y))
+        raw_frame = await load_image(f"bite/{i}.png")
+        frame.paste(raw_frame, mask=raw_frame)
+        frames.append(frame)
+    frames.extend(raw_frames[6:])
+    return save_gif(frames, 0.07)
+
+
+async def police(users: List[UserInfo], **kwargs) -> BytesIO:
+    img = users[0].img
+    frame = await load_image("police/0.png")
+    bg = Image.new("RGBA", frame.size)
+    bg.paste(resize(img, (245, 245)), (224, 46))
+    bg.paste(frame, mask=frame)
+    return save_jpg(bg)
